@@ -122,7 +122,7 @@ class webapp extends WAP_private
             'WHERE '.
                 'act.id = pro.ref_account AND '.
                 'sex.id = pro.ref_sex AND '.
-                'act.id = fri.ref_account AND '.
+                'act.id = fri.ref_friend AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
                 'fri.avail = '.AVAIL_ENABLE.' AND '.
                 'fri.status = '.STATUS_FRIEND_THROW.' AND '.
@@ -179,12 +179,47 @@ class webapp extends WAP_private
         /* アクション処理 */
         if ($this->objdb->exec($sql)){
             $this->insert_friends($result['ref_friend']);
+            $this->update_friend_number($this->account['id']);
+            $this->update_friend_number($result['ref_friend']);
             $this->send_friends();
             header('Location: '.HTTP_ACTION.$pages[$this->status]);
             exit();
         }
     }
 
+    /**
+     * 友達数の設定
+     *
+     * @access private
+     * @param integer $ref_account
+     * @return void
+     */
+    function update_friend_number($ref_account)
+    {
+        $sql=
+            'SELECT '.
+                'count(id) as ct '.
+            'FROM '.
+                DB_PREFIX.'fri_friends '.
+            'WHERE '.
+                'avail = '.AVAIL_ENABLE.' AND '.
+                'status = '.STATUS_FRIEND_CONNECT.' AND '.
+                'ref_account = '.$ref_account;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        $sql =
+            'UPDATE '.
+                DB_PREFIX.'act_account '.
+            'SET '.
+                'friend_number ='.$result['ct'].' '.
+            'WHERE '.
+                'id='.$ref_account;
+        $this->objdb->exec($sql);
+    }
+
     /**
      * 相手用の友達リスト追加
      *
@@ -238,7 +273,7 @@ class webapp extends WAP_private
                 DB_PREFIX.'fri_friends fri '.
             'WHERE '.
                 'act.id = pro.ref_account AND '.
-                'act.id = fri.ref_account AND '.
+                'act.id = fri.ref_friend AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
                 'fri.avail = '.AVAIL_ENABLE.' AND '.
                 'fri.id = '.$this->ref_friends;
