@@ -20,6 +20,8 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/01/21] お友達のお友達名簿を修正
+--      [2007/01/21] お友達の招待名簿を追加
 --      [2006/09/17] 印刷用テーブルの追加
 --      [2006/09/16] デザインテーマの修正 背景の追加
 --      [2006/09/05] 作成
@@ -528,17 +530,29 @@ CREATE TABLE `sns_fri_friends` (
   `modify` timestamp NOT NULL,
   `avail` int(11),
   `status` int(11) NOT NULL,
-  `invite` int(11),
   `ref_account` int(11) NOT NULL,
-  `ref_friend` int(11),
-  `email` blob,
-  `email_hash` varchar(32),
+  `ref_friend` int(11) NOT NULL,
   `comment` text,
   PRIMARY KEY  (`id`),
   UNIQUE (`ref_account`,`ref_friend`),
   UNIQUE (`email_hash`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
+-- 
+-- お友達の招待名簿
+-- 
+CREATE TABLE `sns_fri_invite` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `modify` timestamp NOT NULL,
+  `ref_account` int(11) NOT NULL,
+  `ref_friend` int(11),
+  `email` blob NOT NULL,
+  `email_hash` varchar(32),
+  `comment` text,
+  PRIMARY KEY  (`id`),
+  UNIQUE (`email_hash`)
+) TYPE=MyISAM AUTO_INCREMENT=1;
+
 -- 
 -- お友達のアクセスログ
 -- 
