@@ -20,6 +20,8 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/01/21] お友達のお友達名簿を修正
+--      [2007/01/21] お友達の招待名簿を追加
 --      [2006/12/17] 作成
 -- ========================================================================
 
@@ -558,17 +560,30 @@ CREATE TABLE sns_fri_friends (
   modify timestamp without time zone NOT NULL,
   avail integer,
   status integer NOT NULL,
-  invite integer,
   ref_account integer NOT NULL,
-  ref_friend integer,
-  email bytea,
-  email_hash varchar(32),
+  ref_friend integer NOT NULL,
   comment text,
   PRIMARY KEY  (id),
   UNIQUE (ref_account,ref_friend),
   UNIQUE (email_hash)
 );
 
+-- 
+-- お友達の招待名簿
+-- 
+CREATE SEQUENCE seq_sns_fri_invite start 1 increment 1 maxvalue 9223372036854775807 minvalue 1 cache 1;
+CREATE TABLE sns_fri_invite (
+  id integer DEFAULT nextval('seq_sns_fri_invite'::text) NOT NULL,
+  modify timestamp without time zone NOT NULL,
+  ref_account integer NOT NULL,
+  ref_friend integer,
+  email bytea NOT NULL,
+  email_hash varchar(32),
+  comment text,
+  PRIMARY KEY  (id),
+  UNIQUE (email_hash)
+);
+
 -- 
 -- お友達のアクセスログ
 -- 
