@@ -20,6 +20,8 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/01/21] お友達のお友達名簿を修正
+--      [2007/01/21] お友達の招待名簿を追加
 --      [2006/09/17] インデックスの記述を消去
 --      [2006/09/16] デザインテーマの修正 背景の追加
 --      [2006/09/11] 印刷用テーブルの追加
@@ -513,14 +515,25 @@ CREATE TABLE 'sns_fri_friends' (
   'modify' timestamp NOT NULL,
   'avail' integer,
   'status' integer NOT NULL,
-  'invite' integer,
+  'ref_account' integer NOT NULL,
+  'ref_friend' integer NOT NULL,
+  'comment' text,
+  PRIMARY KEY  ('id'),
+  UNIQUE ('ref_account','ref_friend')
+);
+
+-- 
+-- お友達の招待名簿
+-- 
+CREATE TABLE 'sns_fri_invite' (
+  'id' integer NOT NULL,
+  'modify' timestamp NOT NULL,
   'ref_account' integer NOT NULL,
   'ref_friend' integer,
-  'email' blob,
+  'email' blob  NOT NULL,
   'email_hash' varchar(32),
   'comment' text,
   PRIMARY KEY  ('id'),
-  UNIQUE ('ref_account','ref_friend'),
   UNIQUE ('email_hash')
 );
 
